#=====================================================================================
# function to simulate, print, and find min and max
getMinMax_withModel <- function(modelfile, dosePerKg,interdoseinterval, reference, weight){
  
  outCc  <- list(name = 'Cc', time = seq(35*interdoseinterval-0.05, 35*interdoseinterval+28, by=0.05))
  
  # parameter values from distribution
  parameters <- data.frame(id = 1,
                           V = 23.8,
                           k = 0.112,
                           k12 = 0.0303,
                           k21 = 0.1)
  
  
  # define treatment
  adm <- list(time=seq(0,38*interdoseinterval,by=interdoseinterval), amount=dosePerKg*weight)
  

  # run simulation of one individual, parameter k is drawn from its distribution, taking into account the covariates
  res  <- simulx(model = modelfile,
                 output  = outCc,
                 treatment = adm,
                 parameter = parameters)
  
  Conc <- res$Cc
  Conc$time <- Conc$time - Conc$time[1]
  
  
  d=data.frame(x1=c(-Inf,-Inf), x2=c(Inf,Inf), y1=c(6,0), y2=c(7,2))
  
  
  maxi <- Conc[which(diff(sign(diff(Conc$Cc)))==-2)+1,]
  mini <- Conc[which(diff(sign(diff(Conc$Cc)))==2)+1,]
  
  if (maxi$Cc[1] > 6 & maxi$Cc[1] < 7){
    colormaxi <- 'green'
  }else{
    colormaxi <- 'red'
  }
  
  if (mini$Cc[1] < 2){
    colormini <- 'green'
  }else{
    colormini <- 'red'
  }
  
  
  if(is.null(reference)){
    reference <- Conc
    
    p1 <- ggplot() + 
      geom_rect(data=d, mapping=aes(xmin=x1, xmax=x2, ymin=y1, ymax=y2),alpha=0.2) +
      geom_line(data=Conc, aes(x=time, y=Cc), color='blue', size=1) +
      scale_x_continuous("Time (hr)",  limits=c(0, 28)) + 
      scale_y_continuous("Concentration (mg/L)", limits=c(0, 8)) +
      theme(legend.position="none") +
      ggtitle(paste0("dose=",formatC(dosePerKg, digits = 2, format = "f")," mg/kg, ","inter-dose=",interdoseinterval," hr")) +
      theme_bw(base_size = 16) +
      theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
      geom_point(data=maxi, aes(x=time, y=Cc), color=colormaxi, size=6, alpha=0.3) +
      geom_point(data=mini, aes(x=time, y=Cc), color=colormini, size=6, alpha=0.3) +
      geom_text(data=Conc,x=25, y=6.5, label="Target for peak") +
      geom_text(data=Conc,x=25, y=1.0, label="Target for trough") 
    
    
  }else{
    p1 <- ggplot() + 
      geom_rect(data=d, mapping=aes(xmin=x1, xmax=x2, ymin=y1, ymax=y2),alpha=0.2) +
      geom_line(data=reference, aes(x=time, y=Cc), color='blue', size=1, alpha=0.15) +
      geom_line(data=Conc, aes(x=time, y=Cc), color='blue', size=1) +
      scale_x_continuous("Time (hr)",  limits=c(0, 28)) + 
      scale_y_continuous("Concentration (mg/L)", limits=c(0, 8)) +
      theme(legend.position="none") +
      ggtitle(paste0("dose=",formatC(dosePerKg, digits = 2, format = "f")," mg/kg, ","inter-dose=",interdoseinterval," hr")) +
      theme_bw(base_size = 12) +
      #theme(plot.background=element_rect(fill = "gray")) +
      theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
      geom_point(data=maxi, aes(x=time, y=Cc), color=colormaxi, size=6, alpha=0.3) +
      geom_point(data=mini, aes(x=time, y=Cc), color=colormini, size=6, alpha=0.3) +
      geom_text(data=Conc,x=25, y=6.5, label="Target for peak") +
      geom_text(data=Conc,x=25, y=1.0, label="Target for trough") 
  }
  
  
  
  print(p1)
  
  result <- list(min=mini$Cc[1], max=maxi$Cc[1], ref=reference)
  return(result)
}
