# GOAL: show an overview of simulx features

# loading needed libraries
library(mlxR)
library(gridExtra)

#================================================================================

# simulate the project without any change, and plot the observed values.
# individuals, treatment, measurement times, covariates are taken from the data set
# parameters are those estimated by monolix (file estimates.txt)


# define project file
project.file <- '../monolixProjects/project_07.mlxtran'

# simulation
res1  <- simulx(project = project.file)

#plotting
print(ggplotmlx(data=res1$y) + 
        geom_point(aes(x=time, y=y, colour=id)) +
        geom_line(aes(x=time, y=y, colour=id)) +
        scale_x_continuous("Time") + scale_y_continuous("Observed concentration") +
        theme(legend.position="none"))

#==============================================================================================

# simulate the project with the following changes:
# - 3 administrations of 80mg at time 0, 8 and 16 for all individuals
# - less individuals (10)
# - higher V_pop parameter value
# - denser measurements times


# define administration schedule
adm <- list(time=c(0,8,16), amount=80)

# define number of individuals
N <- 10

# define observation times and simulation outputs
outy  <- list(name = 'y', time = c(0,1,2,5,8,9,10,13,16,17,18,21))
outCc  <- list(name = 'Cc', time = seq(0,25, by=0.1))

# change some parameter values (others are taken from the estimates.txt file)
param <- c(V_pop=30)

# simulation
res2  <- simulx(project = project.file,
                output  = list(outy, outCc),
                treatment = adm,
                group = list(size=N),
                parameter = param)

# plotting
p2_1 <- ggplotmlx(data=res2$Cc) + 
        geom_line(aes(x=time, y=Cc, colour=id)) +
        scale_x_continuous("Time (hr)") + scale_y_continuous("Predicted conc. (mg/L)") +
        theme(legend.position="none")

p2_2 <- ggplotmlx(data=res2$y) + 
  geom_point(aes(x=time, y=y, colour=id)) +
  scale_x_continuous("Time (hr)") + scale_y_continuous("Observed conc. (mg/L)") +
  theme(legend.position="none")

grid.arrange(p2_1, p2_2)
