# GOAL: find toxicity and efficacy in an entire population
# when using usual treatment 1mg/kg every 8h

# define project file
project.file <- '../monolixProjects/project_07.mlxtran'

# defining the repeated administration. The amount is calculated based on the weight
d <- readDatamlx(project = project.file)
covariates <- d$covariate
dosePerKg <- 1
times <- seq(0,300,by=8)
nbTimes <- length(times)
adm1 <- data.frame(id = rep(1:d$N,each=nbTimes),
                   time = rep(times,d$N),
                   amount = rep(dosePerKg*covariates$WT,each=nbTimes))


# output definition: look at 2 cycles after 35 cycles (to be in steady-state)
outCc  <- list(name = 'Cc', time = seq(279, 295.9, by=0.1))

# number of individuals
N <- 100


# simulation of N=100 individuals
res1  <- simulx(project = project.file,
                output  = outCc,
                treatment = adm1,
                parameter = covariates,
                group = list(size=N))

# defining the target zones for peak and trough concentrations
d=data.frame(x1=c(-Inf,-Inf), x2=c(Inf,Inf), y1=c(6,0), y2=c(7,2))
# calculate the percentiles and plot
pPrct1 <- prctilemlx(res1$Cc, band=list(number=9,level=90)) +
  geom_rect(data=d, mapping=aes(xmin=x1, xmax=x2, ymin=y1, ymax=y2),alpha=0.2) +
  scale_x_continuous("Time (hr)") +
  scale_y_continuous("Concentration (mg/L)", limits = c(0, 9.5)) +
  geom_text(data=res1$Cc,x=293.5, y=6.5, label="Target for peak") +
  geom_text(data=res1$Cc,x=293.5, y=1.0, label="Target for trough") #+
  #theme(plot.background=element_rect(fill = "gray"))
print(pPrct1)

# find the min and max concentration for each individual
#(tapply does divides the Cc vector into groups with same id, before doing the min or max)
maxes1 <- tapply(res1$Cc$Cc,res1$Cc$id,max)
mines1 <- tapply(res1$Cc$Cc,res1$Cc$id,min)

# calculate the percentage of individuals with toxic concentrations 
# (peak concentration above 12mg/L and though concentration above 2mg/L)
pToxic1 <- 100 * length(which(mines1>2)) / length(maxes1)

#calculate the percentage of individuals with efficient concentrations
# (peak concentration above 4mg/L)
pNotEfficient1 <- 100 * length(which(maxes1<6)) / length(maxes1)

cat("\n\nUsing the covariate distribution from the data set: ")
cat("\n - For ",pToxic1,"% of the population, 1mg/kg every 8h will be toxic. ", sep='')
cat("\n - For ",pNotEfficient1,"% of the population, 1mg/kg every 8h will not be effective.", sep='')
# => there is a need of adapting the dosing to each person


